<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://themeforest.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Fc
 * @subpackage Fc/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Fc
 * @subpackage Fc/includes
 * @author     Kamleshyadav <support@pixelnx.com>
 */
class Fc {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Fc_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'FC_VERSION' ) ) {
			$this->version = FC_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'fc';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Fc_Loader. Orchestrates the hooks of the plugin.
	 * - Fc_i18n. Defines internationalization functionality.
	 * - Fc_Admin. Defines all hooks for the admin area.
	 * - Fc_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/fc-class-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/fc-class-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/fc-class-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/fc-class-public.php';

		$this->loader = new Fc_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Fc_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Fc_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Fc_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action('admin_menu', $plugin_admin, 'fc_admin_menus');
		$this->loader->add_action( 'admin_init', $plugin_admin, 'fc_save_option' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Fc_Public( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_bmi_calculation', $plugin_public, 'fc_bmi_calculation' );
		$this->loader->add_action( 'wp_ajax_fc_bmi_calculation', $plugin_public, 'fc_bmi_calculation' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_convert_cmtofoot', $plugin_public, 'fc_convert_cmtofoot' );
		$this->loader->add_action( 'wp_ajax_fc_convert_cmtofoot', $plugin_public, 'fc_convert_cmtofoot' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_convert_foottocm', $plugin_public, 'fc_convert_foottocm' );
		$this->loader->add_action( 'wp_ajax_fc_convert_foottocm', $plugin_public, 'fc_convert_foottocm' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_convert_kgtoibs', $plugin_public, 'fc_convert_kgtoibs' );
		$this->loader->add_action( 'wp_ajax_fc_convert_kgtoibs', $plugin_public, 'fc_convert_kgtoibs' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_convert_ibstokg', $plugin_public, 'fc_convert_ibstokg' );
		$this->loader->add_action( 'wp_ajax_fc_convert_ibstokg', $plugin_public, 'fc_convert_ibstokg' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_water_intake', $plugin_public, 'fc_water_intake' );
		$this->loader->add_action( 'wp_ajax_fc_water_intake', $plugin_public, 'fc_water_intake' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_calorie_calculator', $plugin_public, 'fc_calorie_calculator' );
		$this->loader->add_action( 'wp_ajax_fc_calorie_calculator', $plugin_public, 'fc_calorie_calculator' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_walkdistance_cal', $plugin_public, 'fc_walkdistance_cal' );
		$this->loader->add_action( 'wp_ajax_fc_walkdistance_cal', $plugin_public, 'fc_walkdistance_cal' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_bloodtype_cal', $plugin_public, 'fc_bloodtype_cal' );
		$this->loader->add_action( 'wp_ajax_fc_bloodtype_cal', $plugin_public, 'fc_bloodtype_cal' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_chatboat_option_ajax', $plugin_public, 'fc_chatboat_option_ajax' );
		$this->loader->add_action( 'wp_ajax_fc_chatboat_option_ajax', $plugin_public, 'fc_chatboat_option_ajax' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_fc_diet_chart_ajax', $plugin_public, 'fc_diet_chart_ajax' );
		$this->loader->add_action( 'wp_ajax_fc_diet_chart_ajax', $plugin_public, 'fc_diet_chart_ajax' );		
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Fc_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
